#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
from collections import defaultdict
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-m', '--mapfile', type=str, required=True)
ap.add_argument('-s', '--sep', type=str, default="\t")
ap.add_argument('-c', '--column', type=int, default=3)
ap.add_argument('-t', '--titlecolumn', type=int, default=0)
ap.add_argument('--lower', action="store_true")
args = ap.parse_args()

table = dict()
lower_table = defaultdict(list)

def strip_replace_wikid_entity(ent):
    if ent.startswith("'") and ent.endswith("'"):
        ent = ent.strip("'")
    elif ent.startswith('"') and ent.endswith('"'):
        ent = ent.strip('"')
    return ent.replace('\\\\/', '/')

with open(args.mapfile, 'r') as f:
    for l in f:
        l = l.rstrip("\n")
        ID, title = l.split(args.sep)
        #title = title.strip("\"'").replace('\\\\/', '/')
        title = strip_replace_wikid_entity(title)
        table[title] = ID
        if args.lower:
            lower_table[title.lower()].append(ID)

for l in sys.stdin:
    l = l.rstrip("\n")
    li = l.split(args.sep)
    if len(li) != 2:
        print("Wrong format:%s" % l, file=sys.stderr)
        continue
    cause = table.get(li[0], None)
    effect = table.get(li[1], None)
    if not cause and args.lower:
        cause_tmp_li = lower_table.get(li[0].lower(), None)
        if cause_tmp_li and len(cause_tmp_li) == 1:
            cause = cause_tmp_li[0]
    if not effect and args.lower:
        effect_tmp_li = lower_table.get(li[1].lower(), None)
        if effect_tmp_li and len(effect_tmp_li) == 1:
            effect = effect_tmp_li[0]
    if not cause:
        print("Not found in %s: %s" % (args.mapfile, li[0]), file=sys.stderr)
    if not effect:
        print("Not found in %s: %s" % (args.mapfile, li[1]), file=sys.stderr)
    if not cause or not effect:
        continue
    print("%s\t%s\t#\t%s" % (cause, effect, args.sep.join(li)))
