#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
from collections import defaultdict
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-l', '--langfile', type=str, required=True)
ap.add_argument('-s', '--sep', type=str, default="\t")
ap.add_argument('--wdidfilename', type=str, default="-ce-pairs.wdid")
ap.add_argument('--cefilename', type=str, default="-ce-pairs")
ap.add_argument('--wid1column', type=int, default=0)
ap.add_argument('--wid2column', type=int, default=1)
ap.add_argument('--ce1column', type=int, default=3)
ap.add_argument('--ce2column', type=int, default=4)
ap.add_argument('--cece1column', type=int, default=0)
ap.add_argument('--cece2column', type=int, default=1)
ap.add_argument('--celblcolumn', type=int, default=6)
ap.add_argument('--translang', type=str, default="en")
ap.add_argument('--causelabel', type=str, default="c")
ap.add_argument('--effectlabel', type=str, default="e")
ap.add_argument('--exclude_inclusion', action="store_true")
args = ap.parse_args()

wdidtable = defaultdict(set) # wdid-pair -> (en-c, fr-e, ...)
wdidtrans = dict() # wdid-pair -> targetlang-pair

with open(args.langfile, 'r') as f:
    for l in f:
        l = l.rstrip("\n")
        transflag = True if l == args.translang else False
        cefile = l + args.cefilename
        cset = set()
        eset = set()
        with open(cefile, 'r') as g:
            for m in g:
                m = m.rstrip("\n")
                li = m.split(args.sep)
                ce1 = li[args.cece1column]
                ce2 = li[args.cece2column]
                lbl = li[args.celblcolumn] # c/e
                if lbl == args.causelabel:
                    cset.add(ce1 + args.sep + ce2)
                elif lbl == args.effectlabel:
                    eset.add(ce1 + args.sep + ce2)
                else:
                    print("Unknown label:%s ... %s" % (lbl, m), file=sys.stderr)
                    continue
        wdidfile = l + args.wdidfilename
        with open(wdidfile, 'r') as g:
            for m in g:
                m = m.rstrip("\n")
                li = m.split(args.sep)
                wdid1 = li[args.wid1column]
                wdid2 = li[args.wid2column]
                wdidpair = wdid1 + args.sep + wdid2
                ce1 = li[args.ce1column]
                ce2 = li[args.ce2column]
                if args.exclude_inclusion:
                    ce1l = ce1.lower()
                    ce2l = ce2.lower()
                    if len(ce1l) < len(ce2l):
                        if ce1l in ce2l:
                            continue
                    else:
                        if ce2l in ce1l:
                            continue
                cepair = ce1 + args.sep + ce2
                if cepair in cset:
                    wdidtable[wdidpair].add(l + '-' + args.causelabel)
                if cepair in eset:
                    wdidtable[wdidpair].add(l + '-' + args.effectlabel)
                if transflag:
                    wdidtrans[wdidpair] = cepair

for wdidpair in wdidtable:
    trans = wdidtrans.get(wdidpair, '-' + args.sep + '-')
    result = " ".join(wdidtable[wdidpair])
    sum_ = len(wdidtable[wdidpair])
    print("%s\t%s\tSum\t%i\t%s" % (wdidpair, trans, sum_, result))

