#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-m', '--mapfile', type=str, required=True)
ap.add_argument('-d', '--direction', type=str, required=True)
ap.add_argument('-s', '--sep', type=str, default="\t")
args = ap.parse_args()

if args.direction != 'to' and args.direction != 'from':
    print("Unknown direction:%s" % args.direction, file=sys.stderr)
    sys.exit(1)

def strip_replace_wikid_entity(ent):
    if ent.startswith("'") and ent.endswith("'"):
        ent = ent.strip("'")
    elif ent.startswith('"') and ent.endswith('"'):
        ent = ent.strip('"')
    return ent.replace('\\\\/', '/')

mapdic = dict()

with open(args.mapfile, 'r') as f:
    for l in f:
        l = l.rstrip("\n")
        ID, title = l.split(args.sep)
        #title = title.strip("\"'").replace('\\\\/', '/')
        title = strip_replace_wikid_entity(title)
        if args.direction == 'to':
            mapdic[title] = ID
        else:
            mapdic[ID] = title

for l in sys.stdin:
    l = l.rstrip("\n")
    mapped = mapdic.get(l, None)
    if not mapped:
        print("Not found in %s: %s" % (args.mapfile, l), file=sys.stderr)
        continue
    print("%s\t#\t%s" % (mapped, l))

