#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''  
   Copyright (c) 2019 Yahoo Japan Corporation

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
'''

import sys
import os.path
from collections import defaultdict
import re
import codecs
import argparse

ap = argparse.ArgumentParser()
ap.add_argument('-o', '--outdir', type=str, required=True)
args = ap.parse_args()

if not os.path.exists(args.outdir):
    print("Not found:%s" % args.outdir, file=sys.stderr)
    sys.exit(1)

# ,"id":"Q31",
re_id = re.compile(r",\"id\":\"(.+?)\",")
# :{"site":"jawiki","title":"\u30d9\u30eb\u30ae\u30fc","badges":[]},
re_wiki = re.compile(r":{\"site\":\"([a-zA-Z]+?)wiki\",\"title\":\"(.+?)\",\"badges\":")

results = defaultdict(dict) # lang -> ID -> title

for l in sys.stdin:
    l = l.strip()
    m = re_id.search(l)    
    if not m:
        continue
    ID = m.group(1)
    m = re_wiki.findall(l)
    if not m:
        continue
    for (lang, title) in m:
        try:
            results[lang][ID] = codecs.decode(title, 'unicode-escape')
        except:
            print("Error:%s\t%s\t%s" % (lang, ID, title), file=sys.stderr)
            import traceback
            traceback.print_exc()

for lang in results.keys():
    print("%s" % lang, file=sys.stderr)
    with open(os.path.join(args.outdir, lang), 'a') as f:
        for (ID, title) in results[lang].items():
            # %s instead of %r does not work.
            print("%s\t%r" % (ID, title), file=f)

